@@ -11,48 +11,45 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
-#include <gtk/gtk.h>
-
-#ifndef G_OS_WIN32
-#include <sys/types.h>
 #include <regex.h>
-#endif
-
-#include "widgets.h"
 #include "actions.h"
-#include "attributes.h"
 #include "gtkdialog.h"
 #include "variables.h"
 
-extern gchar *option_include_file;
-
 /* 
 ** This action will close a window. The program remain running.
 ** If we get a window's name, we close that if the name is null
 ** we close the widget's parent window.
+FIXME: close by name
 */
-int 
-action_closewindow(GtkWidget *widget, char *string)
+int action_closewindow(GtkWidget * widget, char *string)
 {
-	GtkWidget *parent_widget;
+	GtkWidget *PWindow;
+	variable *var;
 
-	g_assert(GTK_IS_WIDGET(widget));
+	g_assert(string != NULL);
 #ifdef DEBUG
-	g_message("%s(%p, '%s')", __func__, widget, string);
+	fprintf(stderr, "%s(): Closing: '%s'\n", __func__, string);
+	fflush(stderr);
 #endif
-	parent_widget = gtk_widget_get_toplevel(widget);
-	variables_drop_by_parent(NULL, parent_widget);
-	gtk_widget_destroy(parent_widget);
-	/*
-	 * Now, if this was the last window, we can exit.
-	 */
-	if (variables_count_widgets() == 0) {
-		printf("EXIT=\"closewindow\"\n");
-		print_variables(NULL);
-		gtk_main_quit();
-		exit(EXIT_SUCCESS);
+
+	if (strlen(string) != 0) {
+		var = variables_get_by_name(string);
+		if (var == NULL) {
+			fprintf(stderr, "%s() Window '%s' not found.\n",
+				__func__, string);
+			fflush(stderr);
+			return (-1);
+		}
+		//PWindow = var->Widget;
+		variables_drop_by_parent(NULL, var->ParentWindow);
+		gtk_widget_destroy(GTK_WIDGET(var->ParentWindow));
+		return 0;
 	}
-	return 0;
+
+	//  PWindow=gtk_widget_get_parent_window(widget);
+//  variables_drop_by_parent( NULL, PWindow );
+//  gdk_window_destroy( PWindow ); 
 }
 
 /*
@@ -78,28 +75,35 @@ int action_launchwindow(GtkWidget * widget, char *string)
 	}
 
 	/*
-	 * Let's find the source of the window.
+	 ** We read the window description from the environment variable.
 	 */
-	set_program_source(string);
-
+	program_src = getenv(string);
+	/*
+	 ** If we could not find the window we give a message to the user and
+	 ** exit.
+	 */
+	if (program_src == NULL) {
+		fprintf(stderr, "%s(): Could not find window.\n",
+			__func__);
+		return (-1);
+	}
 	/*
 	 ** We exit the gtk main loop to call the parser to interpret the
 	 ** new code.
 	 */
 	variables_export_all();
-	//gtk_main_quit();
-	gtkdialog_parse();
-	return 0;
+	program_name = string;
+	source = PRG_MEMORY;
+	charsreaded = 0;
+	gtk_main_quit();
+	return (0);
 }
 
-int action_exitprogram(GtkWidget *widget, 
-		char *string)
+int action_exitprogram(GtkWidget * widget, char *string)
 {
 	print_variables(NULL);
-	if (string[0] == '=')
-		printf("EXIT%s", string);
-	else
-		printf("EXIT=\"%s\"\n", string);
+	printf("EXIT%s", string);
+	gtk_main_quit();
 	exit(EXIT_SUCCESS);
 }
 
@@ -120,84 +124,13 @@ int action_savewidget(GtkWidget * widget, char *string)
 ** connect it to the action_fileselection_made function to take
 ** the selected file name.
 */
-#if GTK_CHECK_VERSION(2,4,0)
-int 
-action_fileselect(GtkWidget *widget, 
-		char *string)
-{
-	GtkWidget              *chooser;
-	gint                    response;
-	gchar                  *filename;
-	gchar                  *title = NULL;
-	variable               *var = variables_get_by_name(string);
-	GtkFileChooserAction    action;
-	gchar                  *tmp;
-
-	/*
-	 * The title of the chooser dialog.
-	 */
-	if (var != NULL && attributeset_is_avail(var->Attributes, ATTR_LABEL))
-		title = attributeset_get_first(var->Attributes, ATTR_LABEL);
-	if (title == NULL)
-		title = "GtkDialog";
-	/*
-	 * What type of filenames are accepted?
-	 */
-	tmp = g_object_get_data(G_OBJECT(var->Widget), "accept");
-	if (tmp != NULL) {
-		if (g_ascii_strcasecmp(tmp, "filename") == 0)
-			action = GTK_FILE_CHOOSER_ACTION_OPEN;
-		else if(g_ascii_strcasecmp(tmp, "savefilename") == 0)
-			action = GTK_FILE_CHOOSER_ACTION_SAVE;
-		else if(g_ascii_strcasecmp(tmp, "directory") == 0)
-			action = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
-		else if(g_ascii_strcasecmp(tmp, "newdirectory") == 0)
-			action = GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER;
-		else 
-			action = GTK_FILE_CHOOSER_ACTION_OPEN;
-	} else {
-		action = GTK_FILE_CHOOSER_ACTION_OPEN;
-	}
-		
-	/*
-	 ** We create a new chooser dialog.
-	 */
-	chooser = gtk_file_chooser_dialog_new(title, NULL, action, 
-			GTK_STOCK_OK, GTK_RESPONSE_OK,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			NULL);
-	response = gtk_dialog_run(GTK_DIALOG(chooser));
-	/*
-	 * If the user pressed the OK button we set the target 
-	 * widget.
-	 */
-	switch (response) {
-		case GTK_RESPONSE_CANCEL:
-			/* Nothing to do */
-			break;
-		case GTK_RESPONSE_OK:
-			filename = gtk_file_chooser_get_filename(
-					GTK_FILE_CHOOSER(chooser));
-			variables_set_value(string, filename);
-			g_free(filename);
-			break;
-	}
-	/* We are ready. */
-	gtk_widget_destroy(chooser);
-	return 0;
-}
-
-#else
-
-int 
-action_fileselect(GtkWidget *widget, 
-		char *string)
+int action_fileselect(GtkWidget * widget, char *string)
 {
 	actioncommand *ac;
 	/*
 	 ** We create a new actioncommand.
 	 */
-	ac = g_malloc(sizeof(actioncommand));
+	ac = pip_malloc(sizeof(actioncommand), __func__);
 	ac->source_widget = gtk_file_selection_new("gtkwindow");
 	ac->destination_name = string;
 	gtk_widget_show(ac->source_widget);
@@ -220,15 +153,12 @@ action_fileselect(GtkWidget *widget,
 			 (gpointer) ac);
 	return;
 }
-#endif
 
 /*
 ** This function is called, when the user pressed the OK button in
 ** a fileselection dialog.
 */
-void 
-action_fileselection_made(GtkWidget * w, 
-		actioncommand * ac)
+void action_fileselection_made(GtkWidget * w, actioncommand * ac)
 {
 	/*
 	 ** Let's copy the selected file name to the destination widget.
@@ -278,11 +208,7 @@ int action_removeselected(GtkWidget * widget, char *string)
 	return 0;
 }
 
-int 
-action_append(GtkWidget *widget, 
-		char    *string)
-{
-#ifndef G_OS_WIN32
+int action_append(GtkWidget *widget, char * string){
 	regex_t twoparams;
 	regmatch_t matched[3];
 	char *regular = "[ ]*([A-Za-z_]+),[ ]*([A-Za-z_]+)";
@@ -291,8 +217,11 @@ action_append(GtkWidget *widget,
 	
 	g_assert(string != NULL);
 	
-	if (regcomp(&twoparams, regular, REG_EXTENDED) != 0)
-		g_error("%s(): Internal error: %m", __func__);
+	if (regcomp(&twoparams, regular, REG_EXTENDED) != 0){
+		fprintf(stderr, "%s(): Internal error: %m\n",
+				__func__);
+		exit(EXIT_FAILURE);
+	}
 
 	if (regexec(&twoparams, string, 3, matched, 0) != 0) {
 		yywarning("Insert action needs two parameters.");
@@ -300,10 +229,10 @@ action_append(GtkWidget *widget,
 	}
 	
 	length_from = matched[1].rm_eo - matched[1].rm_so;
-	from = g_malloc(length_from + 1);
+	from = pip_malloc(length_from + 1, __func__);
 
 	length_to = matched[2].rm_eo - matched[2].rm_so;
-	to = g_malloc(length_to + 1);
+	to = pip_malloc(length_to + 1, __func__);
 
 	strncpy(from, string, length_from);
 	from[length_from] = '\0';
@@ -312,9 +241,10 @@ action_append(GtkWidget *widget,
 	to[length_to] = '\0';
 
 	return append_fromto_variable(from, to);
-#else
-	g_warning("%s(): Unimplemented.", __func__);
-#endif
+
+	// FIXME: I have a serious problem with memory allocation!
+	//pip_free(from, __func__);
+	//pip_free(to, __func__);
 }
 
 /*
@@ -342,14 +272,16 @@ int action_shellcommand(GtkWidget * widget, char *string)
 	char *command;
 	variables_export_all();
 
-	if (option_include_file == NULL) {
+	if (includefile == NULL) {
 		system(string);
 		return (0);
 	}
 
-	command = g_strdup_printf("source %s; %s", 
-			option_include_file, string);
+	command =
+	    pip_malloc(strlen(string) + strlen(includefile) + 16,
+		       __func__);
+	sprintf(command, "source %s; %s", includefile, string);
 	system(command);
-	g_free(command);
+	free(command);
 	return;
 }
