@@ -13,15 +13,14 @@
  *
  */
 typedef struct _stackelement {
-	gchar       *cval;
-	int          nwidgets;
-	GtkWidget   *widgets[256];
-	int          widgettypes[256];
+  char       *cval;
+  int         nwidgets;
+  GtkWidget   *widgets[256];
+  int         widgettypes[256];
 } stackelement;
 
 stackelement pop();
 void push(stackelement a);
-void show_without_pop(GtkWidget *window);
 
 #endif
 
