@@ -2,38 +2,27 @@
 #include "gtkdialog.h"
 #include "widgets.h"
 
-extern gboolean option_no_warning;
-
 /*
 ** Local functions...
 */
-static variable *_tree_find(const char *name, variable * actual);
-static void _variables_export(variable * actual);
+static
+variable *_tree_find(const char *name, variable * actual);
+
+static 
+void _variables_export(variable * actual);
 
 extern GtkWidget *window;	/* The actual window */
 variable *root = NULL;
 
-#ifdef DEBUG
-void 
-variables_print_one(variable * var)
-{
-	fprintf(stderr, "Name: %s\n", var->Name);
-	fprintf(stderr, "  Widget: %p\n", var->Widget);
-	fprintf(stderr, "  Type: %s\n", widgets_to_str(var->Type));
-	fprintf(stderr, "  Parent: %p\n", var->ParentWindow);
-	fflush(stderr);
-}
-#endif
-
 /*
 ** This function will create a new variable.
 */
-variable *
-variables_new(const char *name)
+variable *variables_new(const char *name)
 {
 	variable *new;
 #ifdef DEBUG
-	g_message("%s(): start '%s'.", __func__, name);
+	fprintf(stderr, "%s(): start '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
 	/* 
 	 ** If the variable exists we simply returns without making a 
@@ -42,13 +31,14 @@ variables_new(const char *name)
 	if (variables_is_avail_by_name(name))
 		return (variables_get_by_name(name));
 
-	new = g_malloc(sizeof(variable));
+	new = pip_malloc(sizeof(variable), __func__);
 	strncpy(new->Name, name, NAMELEN);
 	/* 
 	 ** Setting the defaults for this variable.
 	 */
 	new->Widget = NULL;
 	new->Attributes = NULL;
+	new->ParentWindow = NULL;
 	new->Type = 0;
 	new->row = -1;
 	new->column = -1;
@@ -59,30 +49,25 @@ variables_new(const char *name)
 
 	_tree_insert(new, NULL);
 #ifdef DEBUG
-	g_message("%s(): end '%s'.", __func__, name);
+	fprintf(stderr, "%s(): end '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
-	return new;
+	return (new);
 }
 
 /*
 ** This function will create a new variable with widget and type.
 */
-variable *
-variables_new_with_widget(
-		AttributeSet *Attr, 
-		tag_attr     *widget_tag_attr,
-		GtkWidget    *widget, 
-		int           type)
+variable *variables_new_with_widget(AttributeSet * Attr,
+				    GtkWidget * widget, int type)
 {
 	char *name;
 	variable *var;
 	int autonamed = FALSE;
 
-	g_assert(Attr != NULL);
-	g_assert(widget != NULL);
-
 #ifdef DEBUG
-	g_message("%s(): Starting.", __func__);
+	fprintf(stderr, "%s(): Starting.\n", __func__);
+	fflush(stderr);
 #endif
 	/*
 	 ** If the widget have no name we create a default one for it.
@@ -110,22 +95,20 @@ variables_new_with_widget(
 	var->Widget = widget;
 	var->Type = type;
 	var->autonamed = autonamed;
-	var->Attributes = Attr;
-	var->widget_tag_attr = widget_tag_attr;
 #ifdef DEBUG
-	g_message("%s(): End.", __func__);
+	fprintf(stderr, "%s(): End.\n", __func__);
+	fflush(stderr);
 #endif
 	return (var);
 }
 
 
-variable *
-variables_set_widget(const char *name, 
-		GtkWidget * widget)
+variable *variables_set_widget(const char *name, GtkWidget * widget)
 {
 	variable *var;
 #ifdef DEBUG
-	g_message("%s(): variable '%s'.", __func__, name);
+	fprintf(stderr, "%s(): variable '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
 	var = variables_get_by_name(name);
 	if (var == NULL)
@@ -135,14 +118,12 @@ variables_set_widget(const char *name,
 	return (var);
 }
 
-#if 0
-variable *
-variables_set_parent(const char *name, 
-		GtkWidget * parent)
+variable *variables_set_parent(const char *name, GtkWidget * parent)
 {
 	variable *var;
 #ifdef DEBUG
-	g_message("%s(): Start with '%s'", __func__, name);
+	fprintf(stderr, "%s(): variable '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
 	var = variables_get_by_name(name);
 	if (var == NULL)
@@ -150,15 +131,13 @@ variables_set_parent(const char *name,
 
 	var->ParentWindow = parent;
 #ifdef DEBUG
-	g_message("%s(): End with '%s'", __func__, name);
+	fprintf(stderr, "%s(): variable '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
-	return var;
+	return (var);
 }
-#endif
 
-variable *
-variables_set_type(const char *name, 
-		int type)
+variable *variables_set_type(const char *name, int type)
 {
 	variable *var;
 #ifdef DEBUG
@@ -173,27 +152,27 @@ variables_set_type(const char *name,
 	return (var);
 }
 
-variable *
-variables_set_attributes(const char *name, 
-		AttributeSet * a)
+variable *variables_set_attributes(const char *name, AttributeSet * a)
 {
 	variable *var;
 #ifdef DEBUG
-	g_message("%s(): start '%s'", __func__, name);
+	fprintf(stderr, "%s(): start '%s'.\n", __func__, name);
+	fflush(stderr);
 #endif
 	var = variables_get_by_name(name);
 	if (var == NULL)
 		var = variables_new(name);
 
 	var->Attributes = a;
+#ifdef DEBUG
+	fprintf(stderr, "%s(): end '%s'.\n", __func__, name);
+	fflush(stderr);
+#endif
 	return (var);
 }
 
 
-variable *
-variables_set_row_column(const char *name, 
-		int row, 
-		int column)
+variable *variables_set_row_column(const char *name, int row, int column)
 {
 	variable *toset;
 #ifdef DEBUG
@@ -216,9 +195,7 @@ variables_set_row_column(const char *name,
 ** it will set a widget's data or insert data to the widget as the
 ** type of the widget make it clear. 
 */
-variable *
-variables_set_value(const char *name, 
-		const char *value)
+variable *variables_set_value(const char *name, char *value)
 {
 	variable *toset;
 #ifdef DEBUG
@@ -244,8 +221,7 @@ variables_set_value(const char *name,
 	return (toset);
 }
 
-variable *
-variables_save(const char *name)
+variable *variables_save(const char *name)
 {
 	variable *var;
 	var = _tree_find(name, NULL);
@@ -271,20 +247,19 @@ variables_save(const char *name)
 ** This function will actualize the variable by reinitializing 
 ** widget.
 */
-variable *
-variables_refresh(const char *name)
+variable *variables_refresh(const char *name)
 {
 	variable *var;
-	
-	g_assert(name != NULL);
 #ifdef DEBUG
-	g_message("%s(%s)", __func__, name);
+	fprintf(stderr, "%s(): start '%s'\n", __func__, name);
+	fflush(stderr);
 #endif
 	var = _tree_find(name, NULL);
-	
-	if (var == NULL || var->Widget == NULL)
-		return NULL;
-	
+	if (var == NULL)
+		return (NULL);
+	if (var->Widget == NULL)
+		return (NULL);
+
 	switch (var->Type) {
 		case WIDGET_ENTRY:
 			widget_entry_refresh(var);
@@ -307,24 +282,17 @@ variables_refresh(const char *name)
 		case WIDGET_CHECKBOX:
 			widget_checkbox_refresh(var);
 			break;
-		case WIDGET_TREE:
-			widget_tree_refresh(var);
-			break;
-#ifdef DEBUG
-		default:
-			if (!option_no_warning)
-				g_warning("%s(): Refresh not implemented "
-					"ont his widget.", __func__);
-#endif
+		//default:
+			//yywarning("Refresh not implemented ont his widget.");
 	}
 #ifdef DEBUG
-	g_message("%s(): end", __func__);
+	fprintf(stderr, "%s(): end '%s'\n", __func__, name);
+	fflush(stderr);
 #endif
-	return var;
+	return (var);
 }
 
-variable *
-variables_enable(const char *name)
+variable *variables_enable(const char *name)
 {
 	variable *var;
 #ifdef DEBUG
@@ -341,8 +309,7 @@ variables_enable(const char *name)
 	return (var);
 }
 
-variable *
-variables_disable(const char *name)
+variable *variables_disable(const char *name)
 {
 	variable *var;
 #ifdef DEBUG
@@ -359,8 +326,7 @@ variables_disable(const char *name)
 	return (var);
 }
 
-gboolean 
-variables_is_avail_by_name(const char *name)
+gboolean variables_is_avail_by_name(const char *name)
 {
 	if (_tree_find(name, NULL) == NULL)
 		return (FALSE);
@@ -370,7 +336,7 @@ variables_is_avail_by_name(const char *name)
 
 variable *variables_get_by_name(const char *name)
 {
-	return _tree_find(name, NULL);
+	return (_tree_find(name, NULL));
 }
 
 
@@ -378,9 +344,7 @@ variable *variables_get_by_name(const char *name)
 ** This function insert a new tree node. The node must have a unique
 ** name or the function will abort the program.
 */
-int 
-_tree_insert(variable * new, 
-		variable * actual)
+int _tree_insert(variable * new, variable * actual)
 {
 	int compare;
 	if (new == NULL) {
@@ -425,15 +389,15 @@ _tree_insert(variable * new,
 ** This function finds the variable by its name and returns the ponter
 ** to it.
 */
-static variable *
-_tree_find(const char *name, variable * actual)
+static
+variable *_tree_find(const char *name, variable * actual)
 {
 	int compare;
 
 	if (actual == NULL)
 		actual = root;
 	if (actual == NULL)
-		return NULL;
+		return (NULL);
 
 	compare = strcmp(name, actual->Name);
 
@@ -442,49 +406,21 @@ _tree_find(const char *name, variable * actual)
 
 	if (compare < 0)
 		if (actual->left != NULL)
-			return _tree_find(name, actual->left);
+			return (_tree_find(name, actual->left));
 		else
-			return NULL;
+			return (NULL);
 
 	if (compare > 0)
 		if (actual->right != NULL)
-			return _tree_find(name, actual->right);
+			return (_tree_find(name, actual->right));
 		else
-			return NULL;
-}
-
-static gint
-do_variables_count_widgets(variable *actual, gint n)
-{
-	if (actual == NULL)
-		actual = root;
-
-	if (actual == NULL)
-		return;
-
-	if (actual->left != NULL)
-		n = do_variables_count_widgets(actual->left, n);
-
-	if (actual->Widget != NULL) 
-		++n;
-
-	if (actual->right != NULL)
-		n = do_variables_count_widgets(actual->right, n);
-
-	return n;
-}
-
-gint 
-variables_count_widgets(void) 
-{
-	return do_variables_count_widgets(NULL, 0);
+			return (NULL);
 }
 
 /*
 ** This function will drop all the widgets with the given parent.
 */
-void 
-variables_drop_by_parent(variable *actual, GtkWidget *Parent)
+void variables_drop_by_parent(variable * actual, GtkWidget * Parent)
 {
 	if (actual == NULL)
 		actual = root;
@@ -494,50 +430,15 @@ variables_drop_by_parent(variable *actual, GtkWidget *Parent)
 	if (actual->left != NULL)
 		variables_drop_by_parent(actual->left, Parent);
 
-	if (actual->Widget != NULL) {
-		g_assert(GTK_IS_WIDGET(actual->Widget));
-		if (gtk_widget_get_toplevel(actual->Widget) == Parent) 
-			actual->Widget = NULL;
-	}
+	if (actual->ParentWindow == Parent)
+		actual->Widget = NULL;
 
 	if (actual->right != NULL)
 		variables_drop_by_parent(actual->right, Parent);
 }
 
-static variable *
-do_find_variable_by_widget(variable *actual,
-		GtkWidget *widget)
-{
-	variable *found;
-
-	if (actual == NULL)
-		return NULL;
-	
-	if (actual->left != NULL) {
-		found = do_find_variable_by_widget(actual->left, widget);
-		if (found != NULL)
-			return found;
-	}
-	
-	if (actual->Widget == widget)
-		return actual;
-
-	if (actual->right != NULL) {
-		return do_find_variable_by_widget(actual->right, widget);
-	}
-
-	return NULL;
-}
-
-variable *
-find_variable_by_widget(GtkWidget *widget)
-{
-	return do_find_variable_by_widget(root, widget);
-}
-
-
-static void 
-_variables_initialize(variable *actual)
+static
+void _variables_initialize(variable * actual)
 {
 	char *socket_id;
 	char command[128];
@@ -574,38 +475,25 @@ _variables_initialize(variable *actual)
 		_variables_initialize(actual->right);
 }
 
-static void 
-_variables_export(variable *actual)
+static
+void _variables_export(variable * actual)
 {
-	char             *value;
-	GList            *itemlist;
-	size_t            length;
-	gint              n;
-	gint              column;
-	gchar  		 *tmp;
-	GtkTreeModel	 *model;
-	GtkTreeIter   	  iter;
-	gchar            *text;
-	gchar            *line;
-	
-#ifdef DEBUG
-	g_message("%s(%p)", __func__, actual);
-#endif
-	
+	char *value;
+	char *oneline;
+	GList *itemlist;
+	size_t length;
+
 	if (actual == NULL)
 		actual = root;
 	if (actual == NULL)
 		return;
-	
-#ifdef DEBUG
-	g_message("    actual->name = '%s'", actual->Name);
-#endif
 
 	if (actual->left != NULL)
 		_variables_export(actual->left);
 
 	if (actual->Widget != NULL) {
-		value = widget_get_text_value(actual->Widget, actual->Type);
+		value =
+		    widget_get_text_value(actual->Widget, actual->Type);
 		/* 
 		 ** FIXME: awfull
 		 */
@@ -615,70 +503,42 @@ _variables_export(variable *actual)
 		}
 		
 		if (value != NULL) {
-			line = g_strdup_printf("%s=%s", actual->Name, value);
-			putenv(line);
+			oneline =
+			    pip_malloc(strlen(actual->Name) +
+				       strlen(value) + 3, __func__);
+			sprintf(oneline, "%s=%s", actual->Name, value);
+			putenv(oneline);
 		}
-
 		//
 		// To export all of the elements in the list
 		//
 		if (actual->Type == WIDGET_LIST) {
-			line = g_strdup_printf("%s_ALL=\"", actual->Name);
 			itemlist = GTK_LIST(actual->Widget)->children;
-			n = 0;
+			length = strlen(actual->Name) + 10;
+
 			while (itemlist != NULL) {
-				if (itemlist->data == NULL) 
-					itemlist = itemlist->next;
-					continue;
-				text = gtk_object_get_user_data(itemlist->data);
-				if (n == 0)
-					tmp = g_strconcat(line, "'", text, "'", NULL);
-				else
-					tmp = g_strconcat(line, " '", text, "'", NULL);
-				g_free(line);
-				line = tmp;
-				++n;
+				if (itemlist->data != NULL)
+					length +=
+					    6 +
+					    strlen(gtk_object_get_user_data
+						   (itemlist->data));
 				itemlist = itemlist->next;
 			}
-			putenv(line);
-		}
-		
 
-		if (actual->Type == WIDGET_TREE) {			
-			model = gtk_tree_view_get_model(GTK_TREE_VIEW(actual->Widget));
-			gtk_tree_model_get_iter_first(model, &iter);
-			/*
-			 * Which column should we exportvariable *variables_get_by_name( const char *name );
-			 */
-			tmp = g_object_get_data(G_OBJECT(actual->Widget), "exported_column");
-			if (tmp != 0)
-				column = atoi(tmp) + FirstDataColumn;
-			else
-				column = FirstDataColumn;
-			
-			line = g_strdup_printf("%s_ALL=\"", actual->Name);
-			n = 0;
-			while (gtk_tree_store_iter_is_valid(GTK_TREE_STORE(model), &iter)) {
-				gtk_tree_model_get(model, &iter, column, &text, -1);
-				if (n == 0)
-					tmp = g_strconcat(line, "'", text, "'", NULL);
-				else
-					tmp = g_strconcat(line, " '", text, "'", NULL);
-
-				g_free(line);
-				line = tmp;
-				g_free(text);
-                                
-				if (!gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter))
-					break;
-				++n;
+			oneline = pip_malloc(length + 1, __func__);
+			sprintf(oneline, "%s_ALL=", actual->Name);
+			itemlist = GTK_LIST(actual->Widget)->children;
+			while (itemlist != NULL) {
+				if (itemlist->data != NULL)
+					sprintf(&oneline[strlen(oneline)],
+						"'%s' ",
+						gtk_object_get_user_data
+						(itemlist->data));
+				itemlist = itemlist->next;
 			}
-			tmp = g_strconcat(line, "\"\n", NULL);
-			g_free(line); line = NULL;
-			putenv(tmp);
+			putenv(oneline);
 		}
 	}
-
 	if (actual->right != NULL)
 		_variables_export(actual->right);
 }
@@ -702,30 +562,21 @@ void variables_initialize_all(void)
 ** This function is called when we want to send the variables values
 ** to the standard output.
 */
-void 
-print_variables(variable * actual)
+void print_variables(variable * actual)
 {
-	char             *value;
-	GList            *itemlist;
-	gint              n;
-	gint              column;
-	gchar  		 *tmp;
-	GtkTreeModel	 *model;
-	GtkTreeIter   	  iter;
-	gchar            *text;
-	gchar            *line;
+	char *value;
+	GList *itemlist;
 
 	if (actual == NULL)
 		actual = root;
-	
 	if (actual == NULL)
 		return;
-	
 	if (actual->left != NULL)
 		print_variables(actual->left);
 
 	if (actual->Widget != NULL && !actual->autonamed) {
-		value = widget_get_text_value(actual->Widget, actual->Type);
+		value =
+		    widget_get_text_value(actual->Widget, actual->Type);
 		/* 
 		 ** FIXME: awfull
 		 */
@@ -738,89 +589,42 @@ print_variables(variable * actual)
 			value = "";
 
 		printf("%s=\"%s\"\n", actual->Name, value);
-		/*
-		 * If  this is a list we print all the items also.
-		 */
-		n = 0;
+		//
+		//
+		//
 		if (actual->Type == WIDGET_LIST) {
 			printf("%s_ALL=\"", actual->Name);
 			itemlist = GTK_LIST(actual->Widget)->children;
 			while (itemlist != NULL) {
-				if (itemlist->data == NULL)
-					goto next_item;
-				if (n == 0)
-					printf("'%s'", gtk_object_get_user_data (itemlist->data));
-				else
-					printf(" '%s'", gtk_object_get_user_data (itemlist->data));
-next_item:
+				if (itemlist->data != NULL)
+					printf("'%s' ",
+					       gtk_object_get_user_data
+					       (itemlist->data));
 				itemlist = itemlist->next;
-				++n;
 			}
 			printf("\"\n");
 		}
-
-		if (actual->Type == WIDGET_TREE) {
-			model = gtk_tree_view_get_model(
-					GTK_TREE_VIEW(actual->Widget));
-			gtk_tree_model_get_iter_first(model, &iter);
-			/*
-			 * Which column should we print?
-			 */
-			tmp = g_object_get_data(G_OBJECT(actual->Widget), "exported_column");
-			if (tmp != 0) {
-				column = atoi(tmp) + FirstDataColumn;
-				//g_message("%s: Exported column: %d", __func__, column);
-				//g_message("%s: FirstDataColumn: %d", __func__, FirstDataColumn);
-			} else {
-				column = FirstDataColumn;
-			}
-			
-			line = g_strdup_printf("%s_ALL=\"", actual->Name);
-			n = 0;
-			while (gtk_tree_store_iter_is_valid(GTK_TREE_STORE(model), &iter)) {
-				gtk_tree_model_get(model, &iter, column, &text, -1);
-				if (n == 0)
-					tmp = g_strconcat(line, "'", text, "'", NULL);
-				else
-					tmp = g_strconcat(line, " '", text, "'", NULL);
-				g_free(line);
-				line = tmp;
-				g_free(text);
-                                
-				if (!gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter))
-					break;
-				++n;
-			}
-			tmp = g_strconcat(line, "\"\n", NULL);
-			g_printf("%s", tmp);
-			g_free(line);
-			g_free(tmp);
-		}
 	}
-	
+
 	if (actual->right != NULL)
 		print_variables(actual->right);
-	
+
 	fflush(stdout);
 }
 
 
-int 
-append_fromto_variable(const char *from, 
-		const char *to)
+int append_fromto_variable(const char *from, const char *to)
 {
-	GtkTreeModel *model;
-	GtkTreeIter   iter;
-	variable     *var_from, *var_to;
-	char         *value;
-	GtkWidget    *item;
-	GList        *glist = NULL;
+	variable *var_from, *var_to;
+	char *value;
+	GtkWidget *item;
+	GList *glist = NULL;
 
 	g_assert(from != NULL);
 	g_assert(to != NULL);
-
 #ifdef DEBUG
-	g_message("%s(): from: '%s' to: '%s'", __func__, from, to);
+	fprintf(stderr, "%s(): from: '%s' to: '%s'\n", __func__, from, to);
+	fflush(stderr);
 #endif
 
 	var_from = _tree_find(from, NULL);
@@ -830,44 +634,41 @@ append_fromto_variable(const char *from,
 		return FALSE;
 	}
 
-	value = g_strdup(widget_get_text_value(var_from->Widget, var_from->Type));
+	value = strdup(widget_get_text_value(var_from->Widget,
+					     var_from->Type));
 
 	if (strlen(value) == 0)
 		return FALSE;
 
 	switch (var_to->Type) {
-		case WIDGET_LIST:
-			item = gtk_list_item_new_with_label(value);
-			gtk_widget_show(item);
-			gtk_object_set_user_data(GTK_OBJECT(item), (gpointer) value);
-			glist = g_list_append(glist, item);
+	case WIDGET_LIST:
+		item = gtk_list_item_new_with_label(value);
+		gtk_widget_show(item);
+		gtk_object_set_user_data(GTK_OBJECT(item),
+					 (gpointer) value);
+		glist = g_list_append(glist, item);
 
-			gtk_list_prepend_items(GTK_LIST(var_to->Widget), glist);
-			gtk_list_select_item(GTK_LIST(var_to->Widget), 0);
+		gtk_list_prepend_items(GTK_LIST(var_to->Widget), glist);
+		gtk_list_select_item(GTK_LIST(var_to->Widget), 0);
 		break;
-		
-		case WIDGET_ENTRY:
-			gtk_entry_set_text(GTK_ENTRY(var_to->Widget), value);
-			break;
-		
-		case WIDGET_EDIT:
-			gtk_text_buffer_insert_at_cursor(
-					gtk_text_view_get_buffer(GTK_TEXT_VIEW(var_to->Widget)), 
-					value, g_utf8_strlen(value, -1));
-			break;
-		case WIDGET_TREE:
-			model = gtk_tree_view_get_model(GTK_TREE_VIEW(var_to->Widget));
-			gtk_tree_store_append(GTK_TREE_STORE(model), &iter, NULL); 
-			gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
-					1, value,
-					-1);
-			break;
-
+	case WIDGET_ENTRY:
+		//gtk_entry_append_text(var_to->Widget, 
+		//              value);
+		gtk_entry_set_text(GTK_ENTRY(var_to->Widget), value);
+		// FIXME: free this memory 
+		break;
+	case WIDGET_EDIT:
+		gtk_text_buffer_insert_at_cursor(
+				gtk_text_view_get_buffer(GTK_TEXT_VIEW(
+						var_to->Widget)),
+				value,
+				strlen(value));
 #if GTK_CHECK_VERSION(2,4,0)
-		case WIDGET_CHOOSER:
-			gtk_file_chooser_add_shortcut_folder(
-					GTK_FILE_CHOOSER(var_to->Widget), 
-					value, NULL);
+	case WIDGET_CHOOSER:
+		gtk_file_chooser_add_shortcut_folder(
+				var_to->Widget,
+                                value,
+				NULL);
 		break;
 #endif
 	default:
@@ -881,8 +682,7 @@ append_fromto_variable(const char *from,
 ** This function will clear the variable by deleting everything from
 ** the widget.
 */
-variable *
-variables_clear(const char *name)
+variable *variables_clear(const char *name)
 {
 	variable *toclear;
 	GList *empty = NULL;
@@ -933,58 +733,48 @@ variables_clear(const char *name)
 /*
 ** This function will remove the selected item from the widget.
 */
-int 
-remove_selected_variable(const char *name)
+int remove_selected_variable(const char *name)
 {
-	GtkTreeSelection *selection;
-	GtkTreeModel     *model;
-	GtkTreeIter       iter;
-	GList            *empty = NULL;
-	variable         *toclear;
+	variable *toclear;
+	GList *empty = NULL;
 
 	g_assert(name != NULL);
 
 #ifdef DEBUG
-	g_message("%s(): variable: %s", __func__, name);
+	fprintf(stderr, "%s(): variable: %s\n", __func__, name);
+	fflush(stderr);
 #endif
-	/*
-	 * Searching for the given variable.
-	 */
 	toclear = _tree_find(name, NULL);
 	if (toclear == NULL)
-		return -1;
-	/*
-	 * Removing the selected item or text range from the widget.
-	 */
+		return (-1);
+
 	switch (toclear->Type) {
 		case WIDGET_ENTRY:
 			gtk_entry_set_text(GTK_ENTRY(toclear->Widget), "");
 			break;
-
 		case WIDGET_LIST:
 			if (GTK_LIST(toclear->Widget)->selection != NULL)
-				gtk_widget_destroy(GTK_WIDGET (GTK_LIST(toclear->Widget)-> selection->data));
+				gtk_widget_destroy(GTK_WIDGET
+					   (GTK_LIST(toclear->Widget)->
+					    selection->data));
 			if (GTK_LIST(toclear->Widget)->children != NULL)
-				gtk_list_select_item(GTK_LIST(toclear->Widget), 0);
-			gtk_signal_emit_by_name(GTK_OBJECT(toclear->Widget), "selection-changed");
+				gtk_list_select_item(
+						GTK_LIST(toclear->Widget), 0);
+			gtk_signal_emit_by_name(GTK_OBJECT(toclear->Widget),
+						"selection-changed");
 			break;
-			
 		case WIDGET_TABLE:
 			if (toclear->row != -1)
-				gtk_clist_remove(GTK_CLIST(toclear->Widget), toclear->row);
+				gtk_clist_remove(GTK_CLIST(toclear->Widget),
+						 toclear->row);
 			break;
-			
 		case WIDGET_EDIT:
-			gtk_text_buffer_delete_selection(gtk_text_view_get_buffer(GTK_TEXT_VIEW(toclear->Widget)), 
-					FALSE, TRUE);
+			gtk_text_buffer_delete_selection(
+				gtk_text_view_get_buffer(GTK_TEXT_VIEW(
+						toclear->Widget)),
+				FALSE,
+				TRUE);
 			break;
-			
-		case WIDGET_TREE:
-			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(toclear->Widget));
-			gtk_tree_selection_get_selected(selection, &model, &iter);		
-			gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
-			break;
-			
 		default:
 			yywarning("Delete not implemented for this widget.");
 	}
@@ -992,13 +782,12 @@ remove_selected_variable(const char *name)
 	return 0;
 }
 
-#ifdef DEBUG
+
 /* 
 ** This is a debug function we use to print all variables to the 
 ** standard error. It will print a lot of information.
 */
-void 
-variables_print_debug(variable * actual)
+void variables_print_debug(variable * actual)
 {
 	if (actual == NULL)
 		actual = root;
@@ -1013,4 +802,12 @@ variables_print_debug(variable * actual)
 	if (actual->right != NULL)
 		variables_print_debug(actual->right);
 }
-#endif
+
+void variables_print_one(variable * var)
+{
+	fprintf(stderr, "Name: %s\n", var->Name);
+	fprintf(stderr, "  Widget: %p\n", var->Widget);
+	fprintf(stderr, "  Type: %s\n", widgets_to_str(var->Type));
+	fprintf(stderr, "  Parent: %p\n", var->ParentWindow);
+	fflush(stderr);
+}
